@@ -1,5 +1,16 @@
 #!/usr/bin/env python
 
+#
+# Copyright 2012 Red Hat Inc.
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published
+# by the Free Software Foundation; either version 2.1 of the licence or (at
+# your option) any later version.
+#
+# See the included COPYING file for more information.
+#
+
 import unittest
 
 from gi.repository import MockService as Mock
@@ -10,6 +21,7 @@ class TestStore(unittest.TestCase):
 		Mock.start("mock-service-normal.py")
 
 	def tearDown(self):
+		Secret.Service.disconnect()
 		Mock.stop()
 
 	def testSynchronous(self):
